==> qtjambi-sensors-6.6.0-sources.jar: io/qt/sensors/QOrientationFilter.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensorFilter</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qorientationfilter.html">QOrientationFilter</a></code></p>
 */
public interface QOrientationFilter extends QtObjectInterface, io.qt.sensors.QSensorFilter
{
    /**
     * @hidden
     * <p>Implementor class for interface {@link io.qt.sensors.QOrientationFilter}</p>
     */
    public static abstract class Impl extends QtObject
        implements io.qt.sensors.QOrientationFilter,
                io.qt.sensors.QSensorFilter
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @QtPropertyMember(enabled=false)
        private Object __rcSensor = null;
        
        @NativeAccess
        private static final class ConcreteWrapper extends QOrientationFilter.Impl {
            
            @NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @QtUninvokable
            public boolean filter(io.qt.sensors.@Nullable QOrientationReading reading){
                return filter_native_QOrientationReading_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reading));
            }
            private native static boolean filter_native_QOrientationReading_ptr(long __this__nativeId, long reading);
            
        }
        
        
        /**
         * Function has no implementation because its native counterpart is private.
         */
        @Deprecated
        @QtUninvokable
        @Override
        public final boolean filter(io.qt.sensors.@Nullable QSensorReading reading) throws QNoImplementationException {
            throw new QNoImplementationException();
        }
        
        /**
         * <p>See <code><a href="https://doc.qt.io/qt/qorientationfilter.html#filter">QOrientationFilter::<wbr>filter(QOrientationReading*)</a></code></p>
         */
        @QtUninvokable
        public abstract boolean filter(io.qt.sensors.@Nullable QOrientationReading reading);
        
        private native static boolean filter_native_QOrientationReading_ptr(long __this__nativeId, long reading);
        
        /**
         * <p>See <code>QSensorFilter::<wbr>setSensor(QSensor*)</code></p>
         */
        @QtUninvokable
        protected void setSensor(io.qt.sensors.@Nullable QSensor sensor){
            setSensor_native_QSensor_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(sensor));
            __rcSensor = sensor;
        }
        
        private native static void setSensor_native_QSensor_ptr(long __this__nativeId, long sensor);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         * @hidden
         */
        @NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qorientationfilter.html#filter">QOrientationFilter::<wbr>filter(QOrientationReading*)</a></code></p>
     */
    @QtUninvokable
    public boolean filter(io.qt.sensors.@Nullable QOrientationReading reading);
    
}

==> qtjambi-sensors-6.6.2-sources.jar: io/qt/sensors/QOrientationFilter.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensorFilter</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qorientationfilter.html">QOrientationFilter</a></code></p>
 */
public interface QOrientationFilter extends QtObjectInterface, io.qt.sensors.QSensorFilter
{
    /**
     * @hidden
     * <p>Implementor class for interface {@link io.qt.sensors.QOrientationFilter}</p>
     */
    public static abstract class Impl extends QtObject
        implements io.qt.sensors.QOrientationFilter,
                io.qt.sensors.QSensorFilter
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @QtPropertyMember(enabled=false)
        private Object __rcSensor = null;
        
        @NativeAccess
        private static final class ConcreteWrapper extends QOrientationFilter.Impl {
            
            @NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @QtUninvokable
            public boolean filter(io.qt.sensors.@Nullable QOrientationReading reading){
                return filter_native_QOrientationReading_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reading));
            }
            private native static boolean filter_native_QOrientationReading_ptr(long __this__nativeId, long reading);
            
        }
        
        
        /**
         * Function has no implementation because its native counterpart is private.
         */
        @Deprecated
        @QtUninvokable
        @Override
        public final boolean filter(io.qt.sensors.@Nullable QSensorReading reading) throws QNoImplementationException {
            throw new QNoImplementationException();
        }
        
        /**
         * <p>See <code><a href="https://doc.qt.io/qt/qorientationfilter.html#filter">QOrientationFilter::<wbr/>filter(QOrientationReading*)</a></code></p>
         */
        @QtUninvokable
        public abstract boolean filter(io.qt.sensors.@Nullable QOrientationReading reading);
        
        private native static boolean filter_native_QOrientationReading_ptr(long __this__nativeId, long reading);
        
        /**
         * <p>See <code>QSensorFilter::<wbr/>setSensor(QSensor*)</code></p>
         */
        @QtUninvokable
        protected void setSensor(io.qt.sensors.@Nullable QSensor sensor){
            setSensor_native_QSensor_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(sensor));
            __rcSensor = sensor;
        }
        
        private native static void setSensor_native_QSensor_ptr(long __this__nativeId, long sensor);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         * @hidden
         */
        @NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qorientationfilter.html#filter">QOrientationFilter::<wbr/>filter(QOrientationReading*)</a></code></p>
     */
    @QtUninvokable
    public boolean filter(io.qt.sensors.@Nullable QOrientationReading reading);
    
}
